Class: Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb

Overview

Client for the CloudQuotas service.

The Cloud Quotas API is an infrastructure service for Google Cloud that lets service consumers list and manage their resource usage limits.

  • List/Get the metadata and current status of the quotas for a service.
  • Create/Update quota preferencess that declare the preferred quota values.
  • Check the status of a quota preference request.
  • List/Get pending and historical quota preference.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#location_path, #quota_info_path, #quota_preference_path, #service_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CloudQuotas client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CloudQuotas client.

Yield Parameters:



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 160

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/api/cloudquotas/v1beta/cloudquotas_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @cloud_quotas_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @cloud_quotas_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CloudQuotas Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CloudQuotas clients
::Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 68

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CloudQuotas", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_quota_infos.timeout = 60.0
    default_config.rpcs.list_quota_infos.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_quota_info.timeout = 60.0
    default_config.rpcs.get_quota_info.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_quota_preferences.timeout = 60.0
    default_config.rpcs.list_quota_preferences.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_quota_preference.timeout = 60.0
    default_config.rpcs.get_quota_preference.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_quota_preference.timeout = 60.0
    default_config.rpcs.create_quota_preference.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_quota_preference.timeout = 60.0
    default_config.rpcs.update_quota_preference.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the CloudQuotas Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



130
131
132
133
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 130

def configure
  yield @config if block_given?
  @config
end

#create_quota_preference(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference #create_quota_preference(parent: nil, quota_preference_id: nil, quota_preference: nil, ignore_safety_checks: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

Creates a new QuotaPreference that declares the desired value for a quota.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::CreateQuotaPreferenceRequest.new

# Call the create_quota_preference method.
result = client.create_quota_preference request

# The returned object is of type Google::Cloud::CloudQuotas::V1beta::QuotaPreference.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 674

def create_quota_preference request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::CreateQuotaPreferenceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_quota_preference..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_quota_preference.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_quota_preference.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :create_quota_preference, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_quota_info(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaInfo #get_quota_info(name: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaInfo

Retrieve the QuotaInfo of a quota for a project, folder or organization.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::GetQuotaInfoRequest.new

# Call the get_quota_info method.
result = client.get_quota_info request

# The returned object is of type Google::Cloud::CloudQuotas::V1beta::QuotaInfo.
p result

Overloads:

  • #get_quota_info(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaInfo

    Pass arguments to get_quota_info via a request object, either of type GetQuotaInfoRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudQuotas::V1beta::GetQuotaInfoRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_quota_info(name: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaInfo

    Pass arguments to get_quota_info via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the quota info.

      An example name: projects/123/locations/global/services/compute.googleapis.com/quotaInfos/CpusPerProjectPerRegion

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 372

def get_quota_info request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::GetQuotaInfoRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_quota_info..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_quota_info.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_quota_info.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :get_quota_info, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_quota_preference(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference #get_quota_preference(name: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

Gets details of a single QuotaPreference.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::GetQuotaPreferenceRequest.new

# Call the get_quota_preference method.
result = client.get_quota_preference request

# The returned object is of type Google::Cloud::CloudQuotas::V1beta::QuotaPreference.
p result

Overloads:

  • #get_quota_preference(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

    Pass arguments to get_quota_preference via a request object, either of type GetQuotaPreferenceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudQuotas::V1beta::GetQuotaPreferenceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_quota_preference(name: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

    Pass arguments to get_quota_preference via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Name of the resource

      Example name: projects/123/locations/global/quota_preferences/my-config-for-us-east1

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 579

def get_quota_preference request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::GetQuotaPreferenceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_quota_preference..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_quota_preference.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_quota_preference.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :get_quota_preference, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_quota_infos(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaInfo> #list_quota_infos(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaInfo>

Lists QuotaInfos of all quotas for a given project, folder or organization.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::ListQuotaInfosRequest.new

# Call the list_quota_infos method.
result = client.list_quota_infos request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudQuotas::V1beta::QuotaInfo.
  p item
end

Overloads:

  • #list_quota_infos(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaInfo>

    Pass arguments to list_quota_infos via a request object, either of type ListQuotaInfosRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudQuotas::V1beta::ListQuotaInfosRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_quota_infos(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaInfo>

    Pass arguments to list_quota_infos via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent value of QuotaInfo resources. Listing across different resource containers (such as 'projects/-') is not allowed.

      Example names: projects/123/locations/global/services/compute.googleapis.com folders/234/locations/global/services/compute.googleapis.com organizations/345/locations/global/services/compute.googleapis.com

    • page_size (::Integer) (defaults to: nil)

      Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 282

def list_quota_infos request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::ListQuotaInfosRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_quota_infos..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_quota_infos.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_quota_infos.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :list_quota_infos, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_quotas_stub, :list_quota_infos, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_quota_preferences(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaPreference> #list_quota_preferences(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaPreference>

Lists QuotaPreferences in a given project, folder or organization.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::ListQuotaPreferencesRequest.new

# Call the list_quota_preferences method.
result = client.list_quota_preferences request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference.
  p item
end

Overloads:

  • #list_quota_preferences(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaPreference>

    Pass arguments to list_quota_preferences via a request object, either of type ListQuotaPreferencesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudQuotas::V1beta::ListQuotaPreferencesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_quota_preferences(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudQuotas::V1beta::QuotaPreference>

    Pass arguments to list_quota_preferences via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent value of QuotaPreference resources. Listing across different resource containers (such as 'projects/-') is not allowed.

      When the value starts with 'folders' or 'organizations', it lists the QuotaPreferences for org quotas in the container. It does not list the QuotaPreferences in the descendant projects of the container.

      Example parents: projects/123/locations/global

    • page_size (::Integer) (defaults to: nil)

      Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.

    • page_token (::String) (defaults to: nil)

      Optional. A token identifying a page of results the server should return.

    • filter (::String) (defaults to: nil)

      Optional. Filter result QuotaPreferences by their state, type, create/update time range.

      Example filters: reconciling=true AND request_type=CLOUD_CONSOLE, reconciling=true OR creation_time>2022-12-03T10:30:00

    • order_by (::String) (defaults to: nil)

      Optional. How to order of the results. By default, the results are ordered by create time.

      Example orders: quota_id, service, create_time

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 489

def list_quota_preferences request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::ListQuotaPreferencesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_quota_preferences..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_quota_preferences.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_quota_preferences.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :list_quota_preferences, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_quotas_stub, :list_quota_preferences, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


216
217
218
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 216

def logger
  @cloud_quotas_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


140
141
142
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 140

def universe_domain
  @cloud_quotas_stub.universe_domain
end

#update_quota_preference(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference #update_quota_preference(update_mask: nil, quota_preference: nil, allow_missing: nil, validate_only: nil, ignore_safety_checks: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

Updates the parameters of a single QuotaPreference. It can updates the config in any states, not just the ones pending approval.

Examples:

Basic example

require "google/cloud/cloud_quotas/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudQuotas::V1beta::CloudQuotas::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudQuotas::V1beta::UpdateQuotaPreferenceRequest.new

# Call the update_quota_preference method.
result = client.update_quota_preference request

# The returned object is of type Google::Cloud::CloudQuotas::V1beta::QuotaPreference.
p result

Overloads:

  • #update_quota_preference(request, options = nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

    Pass arguments to update_quota_preference via a request object, either of type UpdateQuotaPreferenceRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudQuotas::V1beta::UpdateQuotaPreferenceRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_quota_preference(update_mask: nil, quota_preference: nil, allow_missing: nil, validate_only: nil, ignore_safety_checks: nil) ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaPreference

    Pass arguments to update_quota_preference via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. Field mask is used to specify the fields to be overwritten in the QuotaPreference resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.

    • quota_preference (::Google::Cloud::CloudQuotas::V1beta::QuotaPreference, ::Hash) (defaults to: nil)

      Required. The resource being updated

    • allow_missing (::Boolean) (defaults to: nil)

      Optional. If set to true, and the quota preference is not found, a new one will be created. In this situation, update_mask is ignored.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. If set to true, validate the request, but do not actually update. Note that a request being valid does not mean that the request is guaranteed to be fulfilled.

    • ignore_safety_checks (::Array<::Google::Cloud::CloudQuotas::V1beta::QuotaSafetyCheck>) (defaults to: nil)

      The list of quota safety checks to be ignored.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
# File 'lib/google/cloud/cloud_quotas/v1beta/cloud_quotas/client.rb', line 775

def update_quota_preference request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudQuotas::V1beta::UpdateQuotaPreferenceRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_quota_preference..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudQuotas::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.quota_preference&.name
    header_params["quota_preference.name"] = request.quota_preference.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_quota_preference.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_quota_preference.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_quotas_stub.call_rpc :update_quota_preference, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end