Class: Google::Cloud::CloudQuotas::V1beta::QuotaAdjusterSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb

Overview

The QuotaAdjusterSettings resource defines the settings for the Quota Adjuster.

Defined Under Namespace

Modules: Enablement

Instance Attribute Summary collapse

Instance Attribute Details

#enablement::Google::Cloud::CloudQuotas::V1beta::QuotaAdjusterSettings::Enablement

Returns Optional. The configured value of the enablement at the given resource.

Returns:



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end

#etag::String

Returns Optional. The current ETag of the QuotaAdjusterSettings. If an ETag is provided on update and does not match the current server's ETag in the QuotaAdjusterSettings, the request is blocked and returns an ABORTED error. See https://google.aip.dev/134#etags for more details on ETags.

Returns:

  • (::String)

    Optional. The current ETag of the QuotaAdjusterSettings. If an ETag is provided on update and does not match the current server's ETag in the QuotaAdjusterSettings, the request is blocked and returns an ABORTED error. See https://google.aip.dev/134#etags for more details on ETags.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end

#inherited::Boolean

Returns Optional. Indicates whether the setting is inherited or explicitly specified.

Returns:

  • (::Boolean)

    Optional. Indicates whether the setting is inherited or explicitly specified.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end

#inherited_from::String (readonly)

Returns Output only. The resource container from which the setting is inherited. This refers to the nearest ancestor with enablement set (either ENABLED or DISABLED). The value can be an organizations/{organization_id}, folders/{folder_id}, or can be 'default' if no ancestor exists with enablement set. The value will be empty when enablement is directly set on this container.

Returns:

  • (::String)

    Output only. The resource container from which the setting is inherited. This refers to the nearest ancestor with enablement set (either ENABLED or DISABLED). The value can be an organizations/{organization_id}, folders/{folder_id}, or can be 'default' if no ancestor exists with enablement set. The value will be empty when enablement is directly set on this container.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end

#name::String

Returns Identifier. Name of the configuration, in the formats below:

  • For a project: projects/PROJECT_NUMBER/locations/global/quotaAdjusterSettings
  • For a folder: folders/FOLDER_NUMBER/locations/global/quotaAdjusterSettings
  • For an organization: organizations/ORGANIZATION_NUMBER/locations/global/quotaAdjusterSettings.

Returns:

  • (::String)

    Identifier. Name of the configuration, in the formats below:

    • For a project: projects/PROJECT_NUMBER/locations/global/quotaAdjusterSettings
    • For a folder: folders/FOLDER_NUMBER/locations/global/quotaAdjusterSettings
    • For an organization: organizations/ORGANIZATION_NUMBER/locations/global/quotaAdjusterSettings


88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the QuotaAdjusterSettings resource was last updated.

Returns:



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'proto_docs/google/api/cloudquotas/v1beta/quota_adjuster_settings.rb', line 88

class QuotaAdjusterSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The enablement status of the quota adjuster.
  module Enablement
    # The quota adjuster is in an unknown state.
    ENABLEMENT_UNSPECIFIED = 0

    # The quota adjuster is enabled.
    ENABLED = 2

    # The quota adjuster is disabled.
    DISABLED = 3
  end
end