Class: Google::Cloud::CloudQuotas::V1beta::QuotaPreference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/cloudquotas/v1beta/resources.rb

Overview

QuotaPreference represents the preferred quota configuration specified for a project, folder or organization. There is only one QuotaPreference resource for a quota value targeting a unique set of dimensions.

Defined Under Namespace

Classes: DimensionsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#contact_email::String

Returns Input only. An email address that can be used to contact the user, in case Google Cloud needs more information to make a decision before additional quota can be granted.

When requesting a quota increase, the email address is required. When requesting a quota decrease, the email address is optional. For example, the email address is optional when the QuotaConfig.preferred_value is smaller than the QuotaDetails.reset_value.

Returns:

  • (::String)

    Input only. An email address that can be used to contact the user, in case Google Cloud needs more information to make a decision before additional quota can be granted.

    When requesting a quota increase, the email address is required. When requesting a quota decrease, the email address is optional. For example, the email address is optional when the QuotaConfig.preferred_value is smaller than the QuotaDetails.reset_value.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Create time stamp.

Returns:



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dimensions::Google::Protobuf::Map{::String => ::String}

Returns Immutable. The dimensions that this quota preference applies to. The key of the map entry is the name of a dimension, such as region, zone, network_id, and the value of the map entry is the dimension value.

If a dimension is missing from the map of dimensions, the quota preference applies to all the dimension values except for those that have other quota preferences configured for the specific value.

Note: QuotaPreferences can only be applied across all values of user and resource dimension. Do not set values for user or resource in the dimension map.

For example: {"provider" : "Example Organization"} where provider is a service-specific quota dimension and Example Organization is the provider name.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Immutable. The dimensions that this quota preference applies to. The key of the map entry is the name of a dimension, such as region, zone, network_id, and the value of the map entry is the dimension value.

    If a dimension is missing from the map of dimensions, the quota preference applies to all the dimension values except for those that have other quota preferences configured for the specific value.

    Note: QuotaPreferences can only be applied across all values of user and resource dimension. Do not set values for user or resource in the dimension map.

    For example: {"provider" : "Example Organization"} where provider is a service-specific quota dimension and Example Organization is the provider name.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Optional. The current etag of the quota preference. If an etag is provided on update and does not match the current server's etag of the quota preference, the request will be blocked and an ABORTED error will be returned. See https://google.aip.dev/134#etags for more details on etags.

Returns:

  • (::String)

    Optional. The current etag of the quota preference. If an etag is provided on update and does not match the current server's etag of the quota preference, the request will be blocked and an ABORTED error will be returned. See https://google.aip.dev/134#etags for more details on etags.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#justification::String

Returns The reason / justification for this quota preference.

Returns:

  • (::String)

    The reason / justification for this quota preference.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Required except in the CREATE requests. The resource name of the quota preference. The path that follows /locations must be /global. For example: projects/123/locations/global/quotaPreferences/my-config-for-us-east1.

Returns:

  • (::String)

    Required except in the CREATE requests. The resource name of the quota preference. The path that follows /locations must be /global. For example: projects/123/locations/global/quotaPreferences/my-config-for-us-east1



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#quota_config::Google::Cloud::CloudQuotas::V1beta::QuotaConfig

Returns Required. Preferred quota configuration.

Returns:



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#quota_id::String

Returns Required. The id of the quota to which the quota preference is applied. A quota name is unique in the service. For example, CpusPerProjectPerRegion.

Returns:

  • (::String)

    Required. The id of the quota to which the quota preference is applied. A quota name is unique in the service. For example, CpusPerProjectPerRegion



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#reconciling::Boolean (readonly)

Returns Output only. Is the quota preference pending Google Cloud approval and fulfillment.

Returns:

  • (::Boolean)

    Output only. Is the quota preference pending Google Cloud approval and fulfillment.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#service::String

Returns Required. The name of the service to which the quota preference is applied.

Returns:

  • (::String)

    Required. The name of the service to which the quota preference is applied.



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Update time stamp.

Returns:



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 209

class QuotaPreference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class DimensionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end