Class: Google::Cloud::CloudQuotas::V1beta::DimensionsInfo
- Inherits:
-
Object
- Object
- Google::Cloud::CloudQuotas::V1beta::DimensionsInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/cloudquotas/v1beta/resources.rb
Overview
The detailed quota information such as effective quota value for a combination of dimensions.
Defined Under Namespace
Classes: DimensionsEntry
Instance Attribute Summary collapse
-
#applicable_locations ⇒ ::Array<::String>
The applicable regions or zones of this dimension.
-
#details ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaDetails
Quota details for the specified dimensions.
-
#dimensions ⇒ ::Google::Protobuf::Map{::String => ::String}
The map of dimensions in key-value pairs.
Instance Attribute Details
#applicable_locations ⇒ ::Array<::String>
Returns The applicable regions or zones of this dimension. The field is set to ['global'] for quotas that are not per region or per zone. Otherwise, it will be set to the list of locations this dimension info is applicable to.
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 297 class DimensionsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#details ⇒ ::Google::Cloud::CloudQuotas::V1beta::QuotaDetails
Returns Quota details for the specified dimensions.
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 297 class DimensionsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dimensions ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The map of dimensions in key-value pairs. The key of a map entry
is "region", "zone", or the name of a service-specific dimension, and the
value of a map entry is the value of the dimension. If a dimension does
not appear in the map of dimensions, the dimensions info applies to all
the dimension values except for those that have another DimensionInfo
instance configured for the specific value.
For example: {"provider" : "Example Organization"} where provider is a
service-specific quota dimension and Example Organization is the provider
name.
297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'proto_docs/google/api/cloudquotas/v1beta/resources.rb', line 297 class DimensionsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class DimensionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |